Rev. Mod. Phys. 94, 045004 (2022) - Ultrafast electron diffraction: Visualizing dynamic states of matter
Description: Understanding the structure and function of both energy and matter is a fundamental goal in science. Various spatiotemporal probes have been developed from electromagnetic waves spanning the entire range of the spectrum to neutrons and charged particles such as electrons. With the development of highly controlled, shorter electron bunches, retrieving dynamic structural information from solid-state and gas-phase samples is now possible at timescales that resolve atomic motion and length scales that resolve atomic positions in even the lightest elements. In this review advances in the generation, manipulation, and characterization of ultrashort electron beams are described.
Date: 2022-12-06

### Ultrafast electron diffraction: Visualizing dynamic states of matter

##### D. Filippetto, P. Musumeci, R. K. Li, B. J. Siwick, M. R. Otto, M. Centurion, and J. P. F. Nunes

##### Rev. Mod. Phys. 94, 045004 – Published 6 December 2022

More
×

- Article
- References
- Citing Articles (48)

PDF HTML Export Citation

  Abstract
  Authors
  Article Text

- Introduction
- Ultrafast Probes for Electron…
- Measuring Dynamics of Matter in a Solid…
- Techniques and Challenges in Gas-Phase…
- Opportunities and Outlook for Ultrafast…
- ACKNOWLEDGMENTS

  References

#### Abstract

Since the discovery of electron-wave duality, electron scattering instrumentation has developed into a powerful array of techniques for revealing the atomic structure of matter. Beyond detecting local lattice variations in equilibrium structures with the highest possible spatial resolution, recent research efforts have been directed toward the long-sought-after dream of visualizing the dynamic evolution of matter in real time. The atomic behavior at ultrafast timescales carries critical information on phase transition and chemical reaction dynamics, the coupling of electronic and nuclear degrees of freedom in materials and molecules, and the correlation among structure, function, and previously hidden metastable or nonequilibrium states of matter. Ultrafast electron pulses play an essential role in this scientific endeavor, and their generation has been facilitated by rapid technical advances in both ultrafast laser and particle accelerator technologies. This review presents a summary of the noteworthy developments in this field in the last few decades. The physics and technology of ultrafast electron beams is presented with an emphasis on the figures of merit most relevant for ultrafast electron diffraction experiments. Recent developments in the generation, manipulation, and characterization of ultrashort electron beams aimed at improving the combined spatiotemporal resolution of these measurements are discussed. The fundamentals of electron scattering from atomic matter and the theoretical frameworks for retrieving dynamic structural information from solid-state and gas-phase samples is described. Essential experimental techniques and several landmark works that have applied these approaches are also highlighted to demonstrate the widening applicability of these methods. Ultrafast electron probes with ever-improving capabilities, combined with other complementary photon-based or spectroscopic approaches, hold tremendous potential for revolutionizing our ability to observe and understand energy and matter at atomic scales.

30 More

- Received 1 February 2021

DOI: https://doi.org/10.1103/RevModPhys.94.045004

© 2022 American Physical Society

#### Physics Subject Headings (PhySH)

Beam control Beam optics Electron beams & optics Laser driven electron acceleration Light-matter interaction Ultrafast phenomena
Accelerators & Beams

#### Authors & Affiliations

D. Filippetto

- Lawrence Berkeley National Laboratory, Berkeley, California 94720, USA

P. Musumeci

- Department of Physics and Astronomy, University of California at Los Angeles, Los Angeles, California 90095, USA

R. K. Li

- Department of Engineering Physics, Tsinghua University, Beijing 100084, China and Key Laboratory of Particle and Radiation Imaging, Tsinghua University, Ministry of Education, Beijing 100084, China

B. J. Siwick and M. R. Otto

- Centre for the Physics of Materials, Department of Physics and Department of Chemistry, McGill University, Montreal, Quebec H3A 2T8, Canada

M. Centurion and J. P. F. Nunes

- University of Nebraska-Lincoln, 855 North 16th Street, Lincoln, Nebraska 68588, USA

Click to Expand

#### Article Text (Subscription Required)

Click to Expand

#### References (Subscription Required)

Click to Expand

##### Issue

Vol. 94, Iss. 4 — October - December 2022

Reuse & Permissions

##### Access Options

- Buy Article »
- Log in with individual APS Journal Account »
- Log in with a username/password provided by your institution »
- Get access through a U.S. public or high school library »

Article Available via CHORUS

Download Accepted Manuscript

#### Authorization Required

Log In

###### Other Options

- Buy Article »
- Find an Institution with the Article »

×

#### Download & Share

PDF Export Reuse & Permissions Citing Articles (48)

- Tweet

×

#### Images

- ###### Figure 1

  Conceptual schematic for a pump-probe UED setup in transmission geometry.

  Reuse & Permissions

- ###### Figure 2

  Differential elastic scattering cross section vs the (a) scattering angle and (b) momentum transfer for 100 keV, 750 keV, and 4 MeV electrons using Eq. (2). (c) Resulting integrated cross section over the entire solid angle (dashed line) and over a small (0.1%) interval around the momentum transfer s=5 Å−1.

  Reuse & Permissions

- ###### Figure 3

  Simulated gas-phase electron scattering for CF 3 I showing (a) the relative contributions of each atom type to the atomic terms, and contributions of the atomic and molecular terms to the total scattering; (b) the simulated s M(s) and (c) PDF (r); and (d) a depiction of the interatomic distances in the molecular terms color coded to the peaks in the PDF (r).

  Reuse & Permissions

- ###### Figure 4

  Ewald sphere construction for diffraction from a crystal using 100 keV and 4 MeV electrons. The reciprocal lattice spacing is set by the crystal lattice constant. The volume of a reciprocal lattice “point” is determined by the size of the crystal.

  Reuse & Permissions

- ###### Figure 5

  Simulated diffraction patterns of a salicylic acid (aspirin) crystal for electron probe beams having coherence lengths of (2 π) 10, 1, and 0.1 nm, respectively.

  Reuse & Permissions

- ###### Figure 6

  Schematic visualization of rms beam properties and emittance. (a),(b) Elliptical contours represent the beam density in phase space. (c) Clarification of the concept of uncorrelated beam divergence (and its relation to the beam emittance).

  Reuse & Permissions

- ###### Figure 7

  Properties on demand: controlling the structure and properties of quantum materials with light. (a) Laser excitation can lead to a photoinduced phase transition on the material’s free-energy landscape, steering the system to a competing ground, metastable, or transient state with dramatically different ordering and properties. Some photoinduced phases can be completely inaccessible at thermal equilibrium. (b) Schematic of an UED experiment on manganite, which exhibits crystalline-lattice (Bragg), orbital (OO), and charge order (CO). Since the diffraction patterns of manganite show separated peaks associated with each order, UED can follow their time dependence and provide deep insights into photoinduced phase transitions like that shown schematically in (a). Adapted from [185].

  Reuse & Permissions

- ###### Figure 8

  Schematic of a general UED setup.

  Reuse & Permissions

- ###### Figure 9

  Requirements of 4D brightness as a function of sample size for different values of momentum transfer ranging from 0.1 to 5 Å−1. The calculations assume that the electron beam fully illuminates the sample area: N e ED=10 6 and R=10. Different curves relate to different momentum transfer values.

  Reuse & Permissions

- ###### Figure 10

  MTE vs excess energy for different cathodes and compared to theory. The minimum of MTE measured corresponds to the ambient temperature (26 meV). Adapted from [240].

  Reuse & Permissions

- ###### Figure 11

  For a (a) dc gun, (b) multicell rf gun, and (c) vhf quarter-wave resonator rf gun used for UED, the schematics of gun geometries are shown with field contour lines (equal-potential lines for dc-gun and field lines for rf guns). The longitudinal (E z, red solid lines) and transverse (E r, blue dashed lines, small offset from the axis) field profiles are also shown.

  Reuse & Permissions

- ###### Figure 12

  (a) For a 1.6 cell S-band rf gun operating at 100 MV/m, the beam energy γ is shown at the gun exit as a function of the launch phase. Inset: evolution of γ in the gun at the maximum energy launch phase, indicated by the blue circle. (b) Relative time of flight from the photocathode to z=15 cm, and the bunch length compression ratio C as a function of the launch phase.

  Reuse & Permissions

- ###### Figure 13

  (a) Dependence of the vacuum dispersion broadening τ v d, gap on the acceleration field E 0 inside a dc accelerating gap for several different initial energy bandwidths of photoelectrons Δ E. (b) Broadening of the bunch length in a drift transport channel for different beam energy and energy spread values.

  Reuse & Permissions

- ###### Figure 14

  Comparison of space-charge-driven evolution of (a) the bunch length and (b) the energy spread of 100 keV and 4 MeV electron beams. The two beams start with otherwise identical initial conditions, including a 100 μ m radius, a 10 nm rad normalized emittance, and a 50 fs rms bunch length.

  Reuse & Permissions

- ###### Figure 15

  (a)–(e) LPS distributions at various locations during the temporal compression process and (f) evolution of the bunch length and energy spread. The electron bunch is positively chirped (a) before the rf buncher due to space-charge forces. The chirp is then (b) minimized and (c) reversed by the rf buncher. In the drift space after the buncher, the electron beams (d) undergo shear motion in LPS toward the vertical orientation and (e) reach minimal bunch length.

  Reuse & Permissions

- ###### Figure 16

  Schematic of a DBA transport line following a rf gun for bunch length and time-of-arrival manipulation. From [238].

  Reuse & Permissions

- ###### Figure 17

  Schematic sketch of the rf linearization process. Nonlinear correlations in the beam longitudinal phase space are removed using a higher harmonic X-band cavity. Adapted from [187].

  Reuse & Permissions

- ###### Figure 18

  (a) 30 kV electron gun. The accelerating gap is 3 mm. (b) Detailed schematic of a 500 kV dc electron gun. From [246]. (c) Maximum accelerating field and output energy for different gap sizes from an electron gun with variable gap. From [217]. (d) SLAC/UCLA/BNL high gradient, pulsed, 1.6 cell S-band rf gun. (e) APEX gun at Lawrence Berkeley National Laboratory, an example of a cw, normal-conducting rf electron gun. (f) Frequency dependence of the breakdown field. Adapted from [272].

  Reuse & Permissions

- ###### Figure 19

  Advanced sources of UED. (a1) Schematic of a LPA electron beamline for UED in which the silicon diffraction patterns consists of Bragg strips due to the relatively large energy spread ([131]). (a2) Transport beamline with collimation utilizing LPA electron bunches to reach 10 fs–level temporal resolution ([88]). Inset: LPA energy spectrum with long-term stability optimized and suitable for MeV-UED purposes ([291]). (b1) Schematic of an ultracold MOT source and the trapping and ionization energy levels of Rb atoms ([224]). (b2) Graphene diffraction pattern obtained with a MOT source and a source temperature retrieved as 10 K ([346]).

  Reuse & Permissions

- ###### Figure 20

  Principle of bunch length characterization using a rf deflecting cavity. The electron beam temporal distribution is mapped onto the transverse density profile.

  Reuse & Permissions

- ###### Figure 21

  Schematic of a synchronization system for an UED setup including rf signals.

  Reuse & Permissions

- ###### Figure 22

  UED experiment with a temporally streaked electron beam. From [245].

  Reuse & Permissions

- ###### Figure 23

  (a) Pure permanent magnet quadrupole. (b) MEMS-based quadrupole. Adapted from [124]. (c) Normal-conducting solenoid. (d) Superconducting solenoid lens. Adapted from [248].

  Reuse & Permissions

- ###### Figure 24

  (a) UED resolving power as a function of the target-screen distance. The Bragg angle is assumed to be 3 mrad. (b) Evolution of the transverse spot size along the beamline for cases with (blue triangles) and without (black squares) the collimating hole. Adapted from [243]. (c) Average beam brightness improvements obtained by aperturing the beam for Gaussian and uniform beam distributions as a function of hole size (normalized to rms spot size).

  Reuse & Permissions

- ###### Figure 25

  Ideal PSF (left column) and its convolution with the camera readout noise (right column). (a),(b) No binning case. (c),(d) 2×2 binning case. Adapted from [239].

  Reuse & Permissions

- ###### Figure 26

  Left panel: principle schematic of direct electron detection. Electron-hole pairs formed in the p-doped epitaxial layer (Epi) by the beam passage form the image signal. Right panel: picture of the TEAM 1K direct detector assembly, including the detector and the in-vacuum electronics. From Peter Denes.

  Reuse & Permissions

- ###### Figure 27

  Phonon-diffuse scattering in materials. (a) Relative strength of the single-phonon structure factor F 1 j(s) as a function of the scattering vector for four different in-plane phonon branches of graphite. Longitudinal acoustic, LA; transverse acoustic, TA; longitudinal optical, LO1; transverse optical, TO2. The hexagonal in-plane Brillouin zone surrounding each Bragg peak is indicated. Two (aribitrary) scattering vectors s 1 and s 2 are shown to indicate the tendency of diffuse scattering features to extend along the scattering vector direction for longitudinal phonons and extend orthogonal to the scattering vector direction for transverse phonons due to the dot product in Eq. (32). Adapted from [281]. (b) Computed diffuse scattering from all phonon modes in crystalline Au at a temperature of 300 K. Brillouin zone boundaries are indicated by white lines. Adapted from [41].

  Reuse & Permissions

- ###### Figure 28

  Common sample types in solid-state ultrafast electron scattering. (a) Metallic wire grids (usually Cu) provide a mesh substrate onto which thin single-crystal flakes can be placed. (b) Etched silicon window with silicon nitride forming a thin transparent region. Powder samples can be grown using various deposition techniques. (c) Large-scale sample concept for a single-shot or irreversible experiment, where each individual and nominally identical sample region can be pumped and probed for only one shot.

  Reuse & Permissions

- ###### Figure 29

  Signal-to-noise considerations in typical solid-state scattering experiments assuming parameters {η, α source, σ int﻿,σ readout}={0.5, 0.1, 6, 5} ([158]). (a) SNR of Bragg scattering as a function of the total collected shots (f rep T experiment) for various bunch densities using typical scattering and SNR paramters. (b) SNR for diffuse scattering using the same SNR parameters as (a) but with a scattering probability p s that is 10−5 smaller than the Bragg scattering.

  Reuse & Permissions

- ###### Figure 30

  Ultrafast photoinduced melting of Au as observed with single-shot UED. MeV-UED patterns of a 35 nm freestanding single-crystal gold film at three different time delays (indicated) relative to the arrival of a femtosecond laser pulse (400 nm) that deposits 1.17 MJ/kg of electronic excitation energy into the material. (a),(b) Depiction of the initial period of lattice heating. Driven by electron-phonon coupling, it is evident in the suppression of the Bragg-peak intensities at early times. (b),(c) The loss of crystalline order, or melting, is evident at later times, as the Bragg spots are replaced by the diffuse ring pattern expected for the liquid phase. Adapted from [231].

  Reuse & Permissions

- ###### Figure 31

  Light-induced charge density wave order in LaTe 3. (a) Structure of LaTe 3 showing two unit cells. (b) Diffraction patterns of LaTe 3 before (lhs; −0.3 ps) and after (rhs; 1.8 ps) photoexcitation showing various Bragg and superlattice peaks. The superlattice peaks before photoexcitation (cyan arrows) result from a periodic lattice distortion along the c axis that is associated with the equilibrium CDW phase (lhs; −0.3 ps). Following photoexcitation new superlattice peaks appear (red circles), indicating the formation of a new CDW order along the a axis at the expense of a weakened CDW order along the c axis (purple circles). Inset: changes in superlattice peak intensities indicating that there is a competition between CDW order along these two axes at equilibrium and that this balance can be tipped by photoexcitation. Adapted from [173].

  Reuse & Permissions

- ###### Figure 32

  Ultrafast electron diffuse scattering of electron-phonon coupling and nonequilibrium phonon relaxation in graphite. (a) Following excitation at 800 nm, the displayed diffuse scattering provides direct information on the time-dependent changes in phonon occupancy. Top left panel: raw electron scattering pattern of the graphite flake indicating the relevant vectors: s, G and k. Other panels show the change in electron scattering intensity [Δ I(s, t)=I(s, t)−I(s, 0)] following photoexcitation for a few representative time delays (indicated). The data are particularly rich. (b) Time-, wave-vector-, and band-dependent changes in phonon population can be extracted from the data shown in (a). Those changes throughout the hexagonal BZ of graphite are shown for three phonon bands (TO, TA, and LA). Adapted from [281].

  Reuse & Permissions

- ###### Figure 33

  Temporal resolution in GUED over time, shown by a few representative experiments. The data were taken from representative experiments conducted by [146], [85], [375], [145], [273],[136], and [391], [392].

  Reuse & Permissions

- ###### Figure 34

  (a),(b) Diagrammatic representation of the effect of velocity mismatch at two different interaction region geometries, with the optical (red dashed lines) and electron (green solid lines) pulses traversing the target sample volume (gray dash-dotted line). W represents the width of the sample volume, and v and c indicate the velocities of the electron and optical pulses. The temporal broadening induced by the geometry in (a) can be calculated as t VM=W/v−W/c. In (b) the pulse-front tilt angle and relative angle between the optical and electron beam compensate for the effect of the velocity mismatch and preserve the temporal resolution of the experiment. (c) Angular dependence of the temporal resolution. (c) Adapted from [327].

  Reuse & Permissions

- ###### Figure 35

  Schematic of the MeV GUED instrument at SLAC. Adapted from [312].

  Reuse & Permissions

- ###### Figure 36

  Block diagram of the data analysis methodologies used in GUED.

  Reuse & Permissions

- ###### Figure 37

  Data analysis of angle-dependent UED data. (a) Simulated diffraction pattern for ground state C F 3 I with a cos 2 Θ distribution. (b) Projected PDF. (c) Slice of the PDF obtained using the Abel inversion of a projected PDF. (d) PDF in polar coordinates, with each peak corresponding to an atom pair marked at the bottom. (e) Panels showing the Δ PDFs obtained from consecutive 10° cones of the difference-diffraction pattern. From [392].

  Reuse & Permissions

×

Sign up to receive regular email alerts from Reviews of Modern Physics

#### Log In

Cancel

- Forgot your username/password?
- Create an account

×

#### Search

#### Article Lookup

###### Paste a citation or DOI

###### Enter a citation

Journal:
Volume:
Article:
×